# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_ohlcv_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,sdk/stream/aggregates_ohlcv_v1/request.proto\x12\x08kaikosdk\x1a\"sdk/core/instrument_criteria.proto\"n\n\x1eStreamAggregatesOHLCVRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12\x11\n\taggregate\x18\x02 \x01(\tB\xa2\x01\n(com.kaiko.sdk.stream.aggregates_ohlcv_v1P\x01ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_ohlcv_v1;aggregates_ohlcv_v1\xaa\x02!KaikoSdk.Stream.AggregatesOHLCVV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregates_ohlcv_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.kaiko.sdk.stream.aggregates_ohlcv_v1P\001ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_ohlcv_v1;aggregates_ohlcv_v1\252\002!KaikoSdk.Stream.AggregatesOHLCVV1'
  _globals['_STREAMAGGREGATESOHLCVREQUESTV1']._serialized_start=94
  _globals['_STREAMAGGREGATESOHLCVREQUESTV1']._serialized_end=204
# @@protoc_insertion_point(module_scope)
