# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/instrument_criteria.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sdk/core/instrument_criteria.proto\x12\x08kaikosdk\"N\n\x12InstrumentCriteria\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x18\n\x10instrument_class\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\tBS\n\x12\x63om.kaiko.sdk.coreP\x01Z+github.com/kaikodata/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.core.instrument_criteria_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.kaiko.sdk.coreP\001Z+github.com/kaikodata/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core'
  _globals['_INSTRUMENTCRITERIA']._serialized_start=48
  _globals['_INSTRUMENTCRITERIA']._serialized_end=126
# @@protoc_insertion_point(module_scope)
