# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_forex_rate_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-sdk/stream/index_forex_rate_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1csdk/core/data_interval.proto\x1a#sdk/stream/index_v1/commodity.proto\"T\n\x16StreamForexIndexPublic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x08ts_event\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"c\n\x16StreamForexIndexDetail\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12,\n\x08ts_event\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8f\x01\n%StreamForexIndexServiceResponseDetail\x12\x34\n\nunderlying\x18\x01 \x01(\x0b\x32 .kaikosdk.StreamForexIndexDetail\x12\x30\n\x06\x66xrate\x18\x02 \x01(\x0b\x32 .kaikosdk.StreamForexIndexDetail\"\x8f\x01\n%StreamForexIndexServiceResponsePublic\x12\x34\n\nunderlying\x18\x01 \x01(\x0b\x32 .kaikosdk.StreamForexIndexPublic\x12\x30\n\x06\x66xrate\x18\x02 \x01(\x0b\x32 .kaikosdk.StreamForexIndexPublic\"\xdc\x02\n%StreamIndexForexRateServiceResponseV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x31\n\tcommodity\x18\x02 \x01(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x44\n\x0b\x63omposition\x18\x04 \x01(\x0b\x32/.kaikosdk.StreamForexIndexServiceResponsePublic\x12\r\n\x05price\x18\x05 \x01(\x01\x12,\n\x08ts_event\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x06\x64\x65tail\x18\x07 \x01(\x0b\x32/.kaikosdk.StreamForexIndexServiceResponseDetailB\xa1\x01\n(com.kaiko.sdk.stream.index_forex_rate_v1P\x01ZPgithub.com/kaikodata/kaiko-go-sdk/stream/index_forex_rate_v1;index_forex_rate_v1\xaa\x02 KaikoSdk.Stream.IndexForexRateV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.index_forex_rate_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.kaiko.sdk.stream.index_forex_rate_v1P\001ZPgithub.com/kaikodata/kaiko-go-sdk/stream/index_forex_rate_v1;index_forex_rate_v1\252\002 KaikoSdk.Stream.IndexForexRateV1'
  _globals['_STREAMFOREXINDEXPUBLIC']._serialized_start=159
  _globals['_STREAMFOREXINDEXPUBLIC']._serialized_end=243
  _globals['_STREAMFOREXINDEXDETAIL']._serialized_start=245
  _globals['_STREAMFOREXINDEXDETAIL']._serialized_end=344
  _globals['_STREAMFOREXINDEXSERVICERESPONSEDETAIL']._serialized_start=347
  _globals['_STREAMFOREXINDEXSERVICERESPONSEDETAIL']._serialized_end=490
  _globals['_STREAMFOREXINDEXSERVICERESPONSEPUBLIC']._serialized_start=493
  _globals['_STREAMFOREXINDEXSERVICERESPONSEPUBLIC']._serialized_end=636
  _globals['_STREAMINDEXFOREXRATESERVICERESPONSEV1']._serialized_start=639
  _globals['_STREAMINDEXFOREXRATESERVICERESPONSEV1']._serialized_end=987
# @@protoc_insertion_point(module_scope)
