# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2
from kaikosdk.stream.market_update_v1 import commodity_pb2 as sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)sdk/stream/market_update_v1/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\x1a\"sdk/core/instrument_criteria.proto\x1a+sdk/stream/market_update_v1/commodity.proto\"\xd7\x02\n\x1bStreamMarketUpdateRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12:\n\x0b\x63ommodities\x18\x02 \x03(\x0e\x32%.kaikosdk.StreamMarketUpdateCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12V\n\rsnapshot_type\x18\x04 \x01(\x0e\x32;.kaikosdk.StreamMarketUpdateRequestV1.OrderbookSnapshotTypeB\x02\x18\x01\"?\n\x15OrderbookSnapshotType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bTEN_PERCENT\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\x42\x96\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.market_update_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1'
  _STREAMMARKETUPDATEREQUESTV1.fields_by_name['snapshot_type']._options = None
  _STREAMMARKETUPDATEREQUESTV1.fields_by_name['snapshot_type']._serialized_options = b'\030\001'
  _globals['_STREAMMARKETUPDATEREQUESTV1']._serialized_start=167
  _globals['_STREAMMARKETUPDATEREQUESTV1']._serialized_end=510
  _globals['_STREAMMARKETUPDATEREQUESTV1_ORDERBOOKSNAPSHOTTYPE']._serialized_start=447
  _globals['_STREAMMARKETUPDATEREQUESTV1_ORDERBOOKSNAPSHOTTYPE']._serialized_end=510
# @@protoc_insertion_point(module_scope)
