# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregated_quote_v2/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,sdk/stream/aggregated_quote_v2/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\"\x92\x01\n\x1eStreamAggregatedQuoteRequestV2\x12\x18\n\x10instrument_class\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x1e\n\x16include_unvetted_price\x18\x04 \x01(\x08\x42\xa2\x01\n(com.kaiko.sdk.stream.aggregated_quote_v2P\x01ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregated_quote_v2;aggregated_quote_v2\xaa\x02!KaikoSdk.Stream.AggregatedQuoteV2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregated_quote_v2.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.kaiko.sdk.stream.aggregated_quote_v2P\001ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregated_quote_v2;aggregated_quote_v2\252\002!KaikoSdk.Stream.AggregatedQuoteV2'
  _globals['_STREAMAGGREGATEDQUOTEREQUESTV2']._serialized_start=89
  _globals['_STREAMAGGREGATEDQUOTEREQUESTV2']._serialized_end=235
# @@protoc_insertion_point(module_scope)
