# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_multi_assets_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/sdk/stream/index_multi_assets_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1csdk/core/data_interval.proto\x1a#sdk/stream/index_v1/commodity.proto\"\x81\x02\n0StreamIndexMultiAssetsServiceResponseComposition\x12\x1d\n\x15underlying_instrument\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\t\x12\r\n\x05quote\x18\x03 \x01(\t\x12\x11\n\texchanges\x18\x04 \x03(\t\x12\x33\n\x13instrument_interval\x18\x05 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x1b\n\x13\x63urrency_conversion\x18\x06 \x01(\t\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd8\x01\n)StreamIndexMultiAssetsServiceResponsePair\x12\x1d\n\x15underlying_instrument\x18\x01 \x01(\t\x12\x36\n\x10underlying_price\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x18\n\x10weighting_factor\x18\x03 \x01(\x01\x12\x16\n\x0e\x63\x61pping_factor\x18\x04 \x01(\x01\x12\"\n\x1a\x63urrency_conversion_factor\x18\x05 \x01(\x01\"\x97\x01\n+StreamIndexMultiAssetsServiceResponsePrices\x12\x13\n\x0bindex_value\x18\x01 \x01(\x01\x12\x0f\n\x07\x64ivisor\x18\x02 \x01(\x01\x12\x42\n\x05pairs\x18\x03 \x03(\x0b\x32\x33.kaikosdk.StreamIndexMultiAssetsServiceResponsePair\"\xa4\x03\n\'StreamIndexMultiAssetsServiceResponseV1\x12\x31\n\tcommodity\x18\x01 \x01(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12\x12\n\nindex_code\x18\x02 \x01(\t\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x12\n\nmain_quote\x18\x04 \x01(\t\x12P\n\x0c\x63ompositions\x18\x05 \x03(\x0b\x32:.kaikosdk.StreamIndexMultiAssetsServiceResponseComposition\x12\x44\n\x05price\x18\x06 \x01(\x0b\x32\x35.kaikosdk.StreamIndexMultiAssetsServiceResponsePrices\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nts_compute\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xa9\x01\n*com.kaiko.sdk.stream.index_multi_assets_v1P\x01ZTgithub.com/kaikodata/kaiko-go-sdk/stream/index_multi_assets_v1;index_multi_assets_v1\xaa\x02\"KaikoSdk.Stream.IndexMultiAssetsV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.index_multi_assets_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.kaiko.sdk.stream.index_multi_assets_v1P\001ZTgithub.com/kaikodata/kaiko-go-sdk/stream/index_multi_assets_v1;index_multi_assets_v1\252\002\"KaikoSdk.Stream.IndexMultiAssetsV1'
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSECOMPOSITION']._serialized_start=194
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSECOMPOSITION']._serialized_end=451
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEPAIR']._serialized_start=454
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEPAIR']._serialized_end=670
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEPRICES']._serialized_start=673
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEPRICES']._serialized_end=824
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEV1']._serialized_start=827
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEV1']._serialized_end=1247
# @@protoc_insertion_point(module_scope)
