# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/trades_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#sdk/stream/trades_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\"\x94\x04\n\x16StreamTradesResponseV1\x12Y\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32:.kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12\x13\n\x0bsequence_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12\x38\n\x04side\x18\t \x01(\x0e\x32*.kaikosdk.StreamTradesResponseV1.TradeSide\x12-\n\x0bts_exchange\x18\n \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\x0b \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\tTradeSide\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x42UY\x10\x01\x12\x08\n\x04SELL\x10\x02\x42{\n\x1e\x63om.kaiko.sdk.stream.trades_v1P\x01Z<github.com/kaikodata/kaiko-go-sdk/stream/trades_v1;trades_v1\xaa\x02\x18KaikoSdk.Stream.TradesV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.trades_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.kaiko.sdk.stream.trades_v1P\001Z<github.com/kaikodata/kaiko-go-sdk/stream/trades_v1;trades_v1\252\002\030KaikoSdk.Stream.TradesV1'
  _STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY._options = None
  _STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY._serialized_options = b'8\001'
  _globals['_STREAMTRADESRESPONSEV1']._serialized_start=108
  _globals['_STREAMTRADESRESPONSEV1']._serialized_end=640
  _globals['_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY']._serialized_start=536
  _globals['_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY']._serialized_end=595
  _globals['_STREAMTRADESRESPONSEV1_TRADESIDE']._serialized_start=597
  _globals['_STREAMTRADESRESPONSEV1_TRADESIDE']._serialized_end=640
# @@protoc_insertion_point(module_scope)
