from setuptools import setup, find_packages

setup(name='kaikosdk',
      version='1.14.1',
      description='Kaiko SDK',
      url='https://www.kaiko.com/',
      author='Kaiko',
      author_email='hello@kaiko.com',
      license='MIT',
      packages=find_packages(),
      zip_safe=False)