# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/commodity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+sdk/stream/market_update_v1/commodity.proto\x12\x08kaikosdk*o\n\x1bStreamMarketUpdateCommodity\x12\x10\n\x0cSMUC_UNKNOWN\x10\x00\x12\x0e\n\nSMUC_TRADE\x10\x01\x12\x14\n\x10SMUC_TOP_OF_BOOK\x10\x02\x12\x18\n\x14SMUC_FULL_ORDER_BOOK\x10\x03\x42\x96\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.market_update_v1.commodity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1'
  _globals['_STREAMMARKETUPDATECOMMODITY']._serialized_start=57
  _globals['_STREAMMARKETUPDATECOMMODITY']._serialized_end=168
# @@protoc_insertion_point(module_scope)
